# API Reference

The public AAAX surface is intentionally small.

## Package

::: aaax

## Bootstrap

::: aaax.bootstrap

## Config

::: aaax.config

## Kernel

::: aaax.kernel

## Policy

::: aaax.policy
